# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, Union

from bungio.models.base import ClientMixin, custom_define
from bungio.models.auth import AuthData
from bungio.utils import AllowAsyncIteration

from bungio.models import HardLinkedUserMembership
from bungio.models import GetCredentialTypesForAccountResponse
from bungio.models import UserSearchResponse
from bungio.models import BungieMembershipType
from bungio.models import UserTheme
from bungio.models import UserSearchPrefixRequest
from bungio.models import BungieCredentialType
from bungio.models import UserMembershipData
from bungio.models import GeneralUser


@custom_define()
class UserRouteInterface(ClientMixin):
    async def get_bungie_net_user_by_id(self, id: int, auth: Optional[AuthData] = None) -> GeneralUser:
        """
        Loads a bungienet user by membership id.

        Args:
            id: The requested Bungie.net membership id.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_bungie_net_user_by_id(id=id, auth=auth)
        return await GeneralUser.from_dict(data=response, client=self._client, id=id, auth=auth)

    async def get_sanitized_platform_display_names(
        self, membership_id: int, auth: Optional[AuthData] = None
    ) -> dict[BungieCredentialType, str]:
        """
        Gets a list of all display names linked to this membership id but sanitized (profanity filtered). Obeys all visibility rules of calling user and is heavily cached.

        Args:
            membership_id: The requested membership id to load.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_sanitized_platform_display_names(membership_id=membership_id, auth=auth)
        return {key: value async for key, value in AllowAsyncIteration(response["Response"].items())}

    async def get_credential_types_for_target_account(
        self, membership_id: int, auth: Optional[AuthData] = None
    ) -> list[GetCredentialTypesForAccountResponse]:
        """
        Returns a list of credential types attached to the requested account

        Args:
            membership_id: The user's membership id
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_credential_types_for_target_account(
            membership_id=membership_id, auth=auth
        )
        return [
            await GetCredentialTypesForAccountResponse.from_dict(
                data=value, client=self._client, membership_id=membership_id, auth=auth
            )
            for value in response["Response"]
        ]

    async def get_available_themes(self, auth: Optional[AuthData] = None) -> list[UserTheme]:
        """
        Returns a list of all available user themes.

        Args:
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_available_themes(auth=auth)
        return [await UserTheme.from_dict(data=value, client=self._client, auth=auth) for value in response["Response"]]

    async def get_membership_data_by_id(
        self, membership_id: int, membership_type: Union[BungieMembershipType, int], auth: Optional[AuthData] = None
    ) -> UserMembershipData:
        """
        Returns a list of accounts associated with the supplied membership ID and membership type. This will include all linked accounts (even when hidden) if supplied credentials permit it.

        Args:
            membership_id: The membership ID of the target user.
            membership_type: Type of the supplied membership ID.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_membership_data_by_id(
            membership_id=membership_id, membership_type=getattr(membership_type, "value", membership_type), auth=auth
        )
        return await UserMembershipData.from_dict(
            data=response, client=self._client, membership_id=membership_id, membership_type=membership_type, auth=auth
        )

    async def get_membership_data_for_current_user(self, auth: AuthData) -> UserMembershipData:
        """
        Returns a list of accounts associated with signed in user. This is useful for OAuth implementations that do not give you access to the token response.

        Warning: Requires Authentication.
            Required oauth2 scopes: ReadBasicUserProfile

        Args:
            auth: Authentication information.

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_membership_data_for_current_user(auth=auth)
        return await UserMembershipData.from_dict(data=response, client=self._client, auth=auth)

    async def get_membership_from_hard_linked_credential(
        self, credential: str, cr_type: Union[BungieCredentialType, int], auth: Optional[AuthData] = None
    ) -> HardLinkedUserMembership:
        """
        Gets any hard linked membership given a credential. Only works for credentials that are public (just SteamID64 right now). Cross Save aware.

        Args:
            credential: The credential to look up. Must be a valid SteamID64.
            cr_type: The credential type. 'SteamId' is the only valid value at present.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_membership_from_hard_linked_credential(
            credential=credential, cr_type=getattr(cr_type, "value", cr_type), auth=auth
        )
        return await HardLinkedUserMembership.from_dict(
            data=response, client=self._client, credential=credential, cr_type=cr_type, auth=auth
        )

    async def search_by_global_name_prefix(
        self, display_name_prefix: str, page: int, auth: Optional[AuthData] = None
    ) -> UserSearchResponse:
        """
        [OBSOLETE] Do not use this to search users, use SearchByGlobalNamePost instead.

        Args:
            display_name_prefix: The display name prefix you're looking for.
            page: The zero-based page of results you desire.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.search_by_global_name_prefix(
            display_name_prefix=display_name_prefix, page=page, auth=auth
        )
        return await UserSearchResponse.from_dict(
            data=response, client=self._client, display_name_prefix=display_name_prefix, page=page, auth=auth
        )

    async def search_by_global_name_post(
        self, data: UserSearchPrefixRequest, page: int, auth: Optional[AuthData] = None
    ) -> UserSearchResponse:
        """
        Given the prefix of a global display name, returns all users who share that name.

        Args:
            data: The required data for this request.
            page: The zero-based page of results you desire.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.search_by_global_name_post(
            page=page, auth=auth, **data.to_dict(_return_to_bungie_case=False)
        )
        return await UserSearchResponse.from_dict(data=response, client=self._client, page=page, auth=auth)



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, TYPE_CHECKING

from bungio.models.base import BaseModel, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import DestinySandboxPerkDefinition


@custom_define()
class DestinyPerkReference(BaseModel):
    """
    The list of perks to display in an item tooltip - and whether or not they have been activated. Perks apply a variety of effects to a character, and are generally either intrinsic to the item or provided in activated talent nodes or sockets.

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        icon_path: The icon for the perk.
        is_active: Whether this perk is currently active. (We may return perks that you have not actually activated yet: these represent perks that you should show in the item's tooltip, but that the user has not yet activated.)
        perk_hash: The hash identifier for the perk, which can be used to look up DestinySandboxPerkDefinition if it exists. Be warned, perks frequently do not have user-viewable information. You should examine whether you actually found a name/description in the perk's definition before you show it to the user.
        visible: Some perks provide benefits, but aren't visible in the UI. This value will let you know if this is perk should be shown in your UI.
        manifest_perk_hash: Manifest information for `perk_hash`
    """

    icon_path: str = custom_field()
    is_active: bool = custom_field()
    perk_hash: int = custom_field()
    visible: bool = custom_field()
    manifest_perk_hash: Optional["DestinySandboxPerkDefinition"] = custom_field(default=None)



from typing import Callable, Coroutine, Optional

from bungio.http.route import Route
from bungio.models.auth import AuthData


class UserSystemOverridesRouteHttpRequests:
    request: Callable[..., Coroutine]

    async def get_user_system_overrides(self, auth: Optional[AuthData] = None, *args, **kwargs) -> dict:
        """
        Get the user-specific system overrides that should be respected alongside common systems.

        Args:
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Raises:
            NotFound: 404 request
            BadRequest: 400 request
            InvalidAuthentication: If authentication is invalid
            TimeoutException: If no connection could be made
            BungieDead: Servers are down
            AuthenticationTooSlow: The authentication key has expired
            BungieException: Relaying the bungie error

        Returns:
            The json response
        """

        return await self.request(Route(path="/UserSystemOverrides/", method="GET", auth=auth))



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from datetime import datetime
from typing import TYPE_CHECKING

from bungio.models.base import BaseModel, custom_define, custom_field

from bungio.models.mixins import DestinyUserMixin

if TYPE_CHECKING:
    from bungio.models import DestinyCollectibleDefinition
    from bungio.models import DestinyRecordDefinition
    from bungio.models import DestinyInventoryItemDefinition


@custom_define()
class PartnerOfferClaimRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_membership_id: _No description given by bungie._
        partner_offer_id: _No description given by bungie._
        transaction_id: _No description given by bungie._
    """

    bungie_net_membership_id: int = custom_field(metadata={"int64": True})
    partner_offer_id: str = custom_field()
    transaction_id: str = custom_field()


@custom_define()
class PartnerOfferSkuHistoryResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        all_offers_applied: _No description given by bungie._
        claim_date: _No description given by bungie._
        localized_description: _No description given by bungie._
        localized_name: _No description given by bungie._
        sku_identifier: _No description given by bungie._
        sku_offers: _No description given by bungie._
        transaction_id: _No description given by bungie._
    """

    all_offers_applied: bool = custom_field()
    claim_date: datetime = custom_field()
    localized_description: str = custom_field()
    localized_name: str = custom_field()
    sku_identifier: str = custom_field()
    sku_offers: list["PartnerOfferHistoryResponse"] = custom_field(
        metadata={"type": """list[PartnerOfferHistoryResponse]"""}
    )
    transaction_id: str = custom_field()


@custom_define()
class PartnerOfferHistoryResponse(BaseModel, DestinyUserMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        apply_date: _No description given by bungie._
        is_consumable: _No description given by bungie._
        localized_description: _No description given by bungie._
        localized_name: _No description given by bungie._
        membership_id: _No description given by bungie._
        membership_type: _No description given by bungie._
        partner_offer_key: _No description given by bungie._
        quantity_applied: _No description given by bungie._
    """

    apply_date: datetime = custom_field()
    is_consumable: bool = custom_field()
    localized_description: str = custom_field()
    localized_name: str = custom_field()
    membership_id: int = custom_field(metadata={"int64": True})
    membership_type: int = custom_field()
    partner_offer_key: str = custom_field()
    quantity_applied: int = custom_field()


@custom_define()
class PartnerRewardHistoryResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        partner_offers: _No description given by bungie._
        twitch_drops: _No description given by bungie._
    """

    partner_offers: list["PartnerOfferSkuHistoryResponse"] = custom_field(
        metadata={"type": """list[PartnerOfferSkuHistoryResponse]"""}
    )
    twitch_drops: list["TwitchDropHistoryResponse"] = custom_field(
        metadata={"type": """list[TwitchDropHistoryResponse]"""}
    )


@custom_define()
class TwitchDropHistoryResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        claim_state: _No description given by bungie._
        created_at: _No description given by bungie._
        description: _No description given by bungie._
        title: _No description given by bungie._
    """

    claim_state: int = custom_field()
    created_at: datetime = custom_field()
    description: str = custom_field()
    title: str = custom_field()


@custom_define()
class BungieRewardDisplay(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        objective_display_properties: _No description given by bungie._
        reward_display_properties: _No description given by bungie._
        user_reward_availability_model: _No description given by bungie._
    """

    objective_display_properties: "RewardDisplayProperties" = custom_field()
    reward_display_properties: "RewardDisplayProperties" = custom_field()
    user_reward_availability_model: "UserRewardAvailabilityModel" = custom_field()


@custom_define()
class UserRewardAvailabilityModel(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        availability_model: _No description given by bungie._
        is_available_for_user: _No description given by bungie._
        is_unlocked_for_user: _No description given by bungie._
    """

    availability_model: "RewardAvailabilityModel" = custom_field()
    is_available_for_user: bool = custom_field()
    is_unlocked_for_user: bool = custom_field()


@custom_define()
class RewardAvailabilityModel(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        collectible_definitions: _No description given by bungie._
        decrypted_token: _No description given by bungie._
        game_earn_by_date: _No description given by bungie._
        has_existing_code: _No description given by bungie._
        has_offer: _No description given by bungie._
        is_loyalty_reward: _No description given by bungie._
        is_offer: _No description given by bungie._
        offer_applied: _No description given by bungie._
        record_definitions: _No description given by bungie._
        redemption_end_date: _No description given by bungie._
        shopify_end_date: _No description given by bungie._
    """

    collectible_definitions: list["CollectibleDefinitions"] = custom_field(
        metadata={"type": """list[CollectibleDefinitions]"""}
    )
    decrypted_token: str = custom_field()
    game_earn_by_date: datetime = custom_field()
    has_existing_code: bool = custom_field()
    has_offer: bool = custom_field()
    is_loyalty_reward: bool = custom_field()
    is_offer: bool = custom_field()
    offer_applied: bool = custom_field()
    record_definitions: list["DestinyRecordDefinition"] = custom_field(
        metadata={"type": """list[DestinyRecordDefinition]"""}
    )
    redemption_end_date: datetime = custom_field()
    shopify_end_date: datetime = custom_field()


@custom_define()
class CollectibleDefinitions(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        collectible_definition: _No description given by bungie._
        destiny_inventory_item_definition: _No description given by bungie._
    """

    collectible_definition: "DestinyCollectibleDefinition" = custom_field()
    destiny_inventory_item_definition: "DestinyInventoryItemDefinition" = custom_field()


@custom_define()
class RewardDisplayProperties(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        description: _No description given by bungie._
        image_path: _No description given by bungie._
        name: _No description given by bungie._
    """

    description: str = custom_field()
    image_path: str = custom_field()
    name: str = custom_field()



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from datetime import datetime
from typing import Optional, Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, custom_define, custom_field

from bungio.models.mixins import DestinyCharacterMixin

if TYPE_CHECKING:
    from bungio.models import DestinyRace
    from bungio.models import DestinyInventoryItemDefinition
    from bungio.models import DestinyRaceDefinition
    from bungio.models import DestinyMilestone
    from bungio.models import DestinyObjectiveProgress
    from bungio.models import DestinyRecordDefinition
    from bungio.models import DestinyCharacterCustomization
    from bungio.models import DestinyColor
    from bungio.models import DestinyActivityModeDefinition
    from bungio.models import DestinyClass
    from bungio.models import DestinyGender
    from bungio.models import DestinyCharacterPeerView
    from bungio.models import BungieMembershipType
    from bungio.models import DestinyQuestStatus
    from bungio.models import DestinyProgression
    from bungio.models import DestinyActivityDefinition
    from bungio.models import DestinyFactionProgression
    from bungio.models import DyeReference
    from bungio.models import DestinyGenderDefinition
    from bungio.models import DestinyClassDefinition
    from bungio.models import DestinyItemPerksComponent
    from bungio.models import DestinyActivity
    from bungio.models import DestinyActivityModeType
    from bungio.models import DestinyArtifactCharacterScoped


@custom_define()
class DestinyCharacterComponent(BaseModel, DestinyCharacterMixin):
    """
    This component contains base properties of the character. You'll probably want to always request this component, but hey you do you.

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        base_character_level: The "base" level of your character, not accounting for any light level.
        character_id: The unique identifier for the character.
        class_hash: Use this hash to look up the character's DestinyClassDefinition.
        class_type: Mostly for historical purposes at this point, this is an enumeration for the character's class. It'll be preferable in the general case to look up the related definition: but for some people this was too convenient to remove.
        date_last_played: The last date that the user played Destiny.
        emblem_background_path: A shortcut path to the user's currently equipped emblem background image. If you're just showing summary info for a user, this is more convenient than examining their equipped emblem and looking up the definition.
        emblem_color: A shortcut for getting the background color of the user's currently equipped emblem without having to do a DestinyInventoryItemDefinition lookup.
        emblem_hash: The hash of the currently equipped emblem for the user. Can be used to look up the DestinyInventoryItemDefinition.
        emblem_path: A shortcut path to the user's currently equipped emblem image. If you're just showing summary info for a user, this is more convenient than examining their equipped emblem and looking up the definition.
        gender_hash: Use this hash to look up the character's DestinyGenderDefinition.
        gender_type: Mostly for historical purposes at this point, this is an enumeration for the character's Gender. It'll be preferable in the general case to look up the related definition: but for some people this was too convenient to remove. And yeah, it's an enumeration and not a boolean. Fight me.
        level_progression: The progression that indicates your character's level. Not their light level, but their character level: you know, the thing you max out a couple hours in and then ignore for the sake of light level.
        light: The user's calculated "Light Level". Light level is an indicator of your power that mostly matters in the end game, once you've reached the maximum character level: it's a level that's dependent on the average Attack/Defense power of your items.
        membership_id: Every Destiny Profile has a membershipId. This is provided on the character as well for convenience.
        membership_type: membershipType tells you the platform on which the character plays. Examine the BungieMembershipType enumeration for possible values.
        minutes_played_this_session: If the user is currently playing, this is how long they've been playing.
        minutes_played_total: If this value is 525,600, then they played Destiny for a year. Or they're a very dedicated Rent fan. Note that this includes idle time, not just time spent actually in activities shooting things.
        percent_to_next_level: A number between 0 and 100, indicating the whole and fractional % remaining to get to the next character level.
        race_hash: Use this hash to look up the character's DestinyRaceDefinition.
        race_type: Mostly for historical purposes at this point, this is an enumeration for the character's race. It'll be preferable in the general case to look up the related definition: but for some people this was too convenient to remove.
        stats: Your character's stats, such as Agility, Resilience, etc... *not* historical stats. You'll have to call a different endpoint for those.
        title_record_hash: If this Character has a title assigned to it, this is the identifier of the DestinyRecordDefinition that has that title information.
        manifest_class_hash: Manifest information for `class_hash`
        manifest_emblem_hash: Manifest information for `emblem_hash`
        manifest_gender_hash: Manifest information for `gender_hash`
        manifest_race_hash: Manifest information for `race_hash`
        manifest_title_record_hash: Manifest information for `title_record_hash`
    """

    base_character_level: int = custom_field()
    character_id: int = custom_field(metadata={"int64": True})
    class_hash: int = custom_field()
    class_type: Union["DestinyClass", int] = custom_field(converter=enum_converter("DestinyClass"))
    date_last_played: datetime = custom_field()
    emblem_background_path: str = custom_field()
    emblem_color: "DestinyColor" = custom_field()
    emblem_hash: int = custom_field()
    emblem_path: str = custom_field()
    gender_hash: int = custom_field()
    gender_type: Union["DestinyGender", int] = custom_field(converter=enum_converter("DestinyGender"))
    level_progression: "DestinyProgression" = custom_field()
    light: int = custom_field()
    membership_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    minutes_played_this_session: int = custom_field(metadata={"int64": True})
    minutes_played_total: int = custom_field(metadata={"int64": True})
    percent_to_next_level: float = custom_field()
    race_hash: int = custom_field()
    race_type: Union["DestinyRace", int] = custom_field(converter=enum_converter("DestinyRace"))
    stats: dict[int, int] = custom_field(metadata={"type": """dict[int, int]"""})
    title_record_hash: int = custom_field()
    manifest_class_hash: Optional["DestinyClassDefinition"] = custom_field(default=None)
    manifest_emblem_hash: Optional["DestinyInventoryItemDefinition"] = custom_field(default=None)
    manifest_gender_hash: Optional["DestinyGenderDefinition"] = custom_field(default=None)
    manifest_race_hash: Optional["DestinyRaceDefinition"] = custom_field(default=None)
    manifest_title_record_hash: Optional["DestinyRecordDefinition"] = custom_field(default=None)


@custom_define()
class DestinyCharacterProgressionComponent(BaseModel):
    """
    This component returns anything that could be considered "Progression" on a user: data where the user is gaining levels, reputation, completions, rewards, etc...

    None
    Attributes:
        checklists: The set of checklists that can be examined for this specific character, keyed by the hash identifier of the Checklist (DestinyChecklistDefinition) For each checklist returned, its value is itself a Dictionary keyed by the checklist's hash identifier with the value being a boolean indicating if it's been discovered yet.
        factions: A dictionary of all known Factions, keyed by the Faction's hash. It contains data about this character's status with the faction.
        milestones: Milestones are related to the simple progressions shown in the game, but return additional and hopefully helpful information for users about the specifics of the Milestone's status.
        progressions: A Dictionary of all known progressions for the Character, keyed by the Progression's hash. Not all progressions have user-facing data, but those who do will have that data contained in the DestinyProgressionDefinition.
        quests: If the user has any active quests, the quests' statuses will be returned here.  Note that quests have been largely supplanted by Milestones, but that doesn't mean that they won't make a comeback independent of milestones at some point.  (Fun fact: quests came back as I feared they would, but we never looped back to populate this... I'm going to put that in the backlog.)
        seasonal_artifact: Data related to your progress on the current season's artifact that can vary per character.
        uninstanced_item_objectives: Sometimes, you have items in your inventory that don't have instances, but still have Objective information. This provides you that objective information for uninstanced items.  This dictionary is keyed by the item's hash: which you can use to look up the name and description for the overall task(s) implied by the objective. The value is the list of objectives for this item, and their statuses.
        uninstanced_item_perks: Sometimes, you have items in your inventory that don't have instances, but still have perks (for example: Trials passage cards). This gives you the perk information for uninstanced items. This dictionary is keyed by item hash, which you can use to look up the corresponding item definition. The value is the list of perks states for the item.
    """

    checklists: dict[int, dict[int, bool]] = custom_field(metadata={"type": """dict[int, dict[int, bool]]"""})
    factions: dict[int, "DestinyFactionProgression"] = custom_field(
        metadata={"type": """dict[int, DestinyFactionProgression]"""}
    )
    milestones: dict[int, "DestinyMilestone"] = custom_field(metadata={"type": """dict[int, DestinyMilestone]"""})
    progressions: dict[int, "DestinyProgression"] = custom_field(metadata={"type": """dict[int, DestinyProgression]"""})
    quests: list["DestinyQuestStatus"] = custom_field(metadata={"type": """list[DestinyQuestStatus]"""})
    seasonal_artifact: "DestinyArtifactCharacterScoped" = custom_field()
    uninstanced_item_objectives: dict[int, list["DestinyObjectiveProgress"]] = custom_field(
        metadata={"type": """dict[int, list[DestinyObjectiveProgress]]"""}
    )
    uninstanced_item_perks: dict[int, "DestinyItemPerksComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyItemPerksComponent]"""}
    )


@custom_define()
class DestinyCharacterRenderComponent(BaseModel):
    """
    Only really useful if you're attempting to render the character's current appearance in 3D, this returns a bare minimum of information, pre-aggregated, that you'll need to perform that rendering. Note that you need to combine this with other 3D assets and data from our servers. Examine the Javascript returned by https://bungie.net/sharedbundle/spasm to see how we use this data, but be warned: the rabbit hole goes pretty deep.

    None
    Attributes:
        custom_dyes: Custom dyes, calculated by iterating over the character's equipped items. Useful for pre-fetching all of the dye data needed from our server.
        customization: This is actually something that Spasm.js *doesn't* do right now, and that we don't return assets for yet. This is the data about what character customization options you picked. You can combine this with DestinyCharacterCustomizationOptionDefinition to show some cool info, and hopefully someday to actually render a user's face in 3D. We'll see if we ever end up with time for that.
        peer_view: A minimal view of: - Equipped items - The rendering-related custom options on those equipped items Combined, that should be enough to render all of the items on the equipped character.
    """

    custom_dyes: list["DyeReference"] = custom_field(metadata={"type": """list[DyeReference]"""})
    customization: "DestinyCharacterCustomization" = custom_field()
    peer_view: "DestinyCharacterPeerView" = custom_field()


@custom_define()
class DestinyCharacterActivitiesComponent(BaseModel):
    """
    This component holds activity data for a character. It will tell you about the character's current activity status, as well as activities that are available to the user.

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        available_activities: The list of activities that the user can play.
        current_activity_hash: If the user is in an activity, this will be the hash of the Activity being played. Note that you must combine this info with currentActivityModeHash to get a real picture of what the user is doing right now. For instance, PVP "Activities" are just maps: it's the ActivityMode that determines what type of PVP game they're playing.
        current_activity_mode_hash: If the user is in an activity, this will be the hash of the activity mode being played. Combine with currentActivityHash to give a person a full picture of what they're doing right now.
        current_activity_mode_hashes: If the user is in an activity, this will be the hashes of the DestinyActivityModeDefinition being played. Combine with currentActivityHash to give a person a full picture of what they're doing right now.
        current_activity_mode_type: And the current activity's most specific mode type, if it can be found.
        current_activity_mode_types: All Activity Modes that apply to the current activity being played, in enum form.
        current_playlist_activity_hash: If the user is in a playlist, this is the hash identifier for the playlist that they chose.
        date_activity_started: The last date that the user started playing an activity.
        last_completed_story_hash: This will have the activity hash of the last completed story/campaign mission, in case you care about that.
        manifest_current_activity_hash: Manifest information for `current_activity_hash`
        manifest_current_activity_mode_hash: Manifest information for `current_activity_mode_hash`
        manifest_current_playlist_activity_hash: Manifest information for `current_playlist_activity_hash`
        manifest_last_completed_story_hash: Manifest information for `last_completed_story_hash`
    """

    available_activities: list["DestinyActivity"] = custom_field(metadata={"type": """list[DestinyActivity]"""})
    current_activity_hash: int = custom_field()
    current_activity_mode_hash: int = custom_field()
    current_activity_mode_hashes: list[int] = custom_field(metadata={"type": """list[int]"""})
    current_activity_mode_type: int = custom_field()
    current_activity_mode_types: list[Union["DestinyActivityModeType", int]] = custom_field(
        converter=enum_converter("DestinyActivityModeType")
    )
    current_playlist_activity_hash: int = custom_field()
    date_activity_started: datetime = custom_field()
    last_completed_story_hash: int = custom_field()
    manifest_current_activity_hash: Optional["DestinyActivityDefinition"] = custom_field(default=None)
    manifest_current_activity_mode_hash: Optional["DestinyActivityModeDefinition"] = custom_field(default=None)
    manifest_current_playlist_activity_hash: Optional["DestinyActivityDefinition"] = custom_field(default=None)
    manifest_last_completed_story_hash: Optional["DestinyActivityDefinition"] = custom_field(default=None)



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import DestinyCollectibleState
    from bungio.models import DestinyPresentationNodeDefinition


@custom_define()
class DestinyCollectiblesComponent(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        collectibles: _No description given by bungie._
        collection_badges_root_node_hash: The hash for the root presentation node definition of Collection Badges.
        collection_categories_root_node_hash: The hash for the root presentation node definition of Collection categories.
        manifest_collection_badges_root_node_hash: Manifest information for `collection_badges_root_node_hash`
        manifest_collection_categories_root_node_hash: Manifest information for `collection_categories_root_node_hash`
    """

    collectibles: dict[int, "DestinyCollectibleComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyCollectibleComponent]"""}
    )
    collection_badges_root_node_hash: int = custom_field()
    collection_categories_root_node_hash: int = custom_field()
    manifest_collection_badges_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )
    manifest_collection_categories_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )


@custom_define()
class DestinyCollectibleComponent(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        state: _No description given by bungie._
    """

    state: Union["DestinyCollectibleState", int] = custom_field(converter=enum_converter("DestinyCollectibleState"))


@custom_define()
class DestinyProfileCollectiblesComponent(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        collectibles: _No description given by bungie._
        collection_badges_root_node_hash: The hash for the root presentation node definition of Collection Badges.
        collection_categories_root_node_hash: The hash for the root presentation node definition of Collection categories.
        newness_flagged_collectible_hashes: The list of collectibles determined by the game as having been "recently" acquired. The game client itself actually controls this data, so I personally question whether anyone will get much use out of this: because we can't edit this value through the API. But in case anyone finds it useful, here it is.
        recent_collectible_hashes: The list of collectibles determined by the game as having been "recently" acquired.
        manifest_collection_badges_root_node_hash: Manifest information for `collection_badges_root_node_hash`
        manifest_collection_categories_root_node_hash: Manifest information for `collection_categories_root_node_hash`
    """

    collectibles: dict[int, "DestinyCollectibleComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyCollectibleComponent]"""}
    )
    collection_badges_root_node_hash: int = custom_field()
    collection_categories_root_node_hash: int = custom_field()
    newness_flagged_collectible_hashes: list[int] = custom_field(metadata={"type": """list[int]"""})
    recent_collectible_hashes: list[int] = custom_field(metadata={"type": """list[int]"""})
    manifest_collection_badges_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )
    manifest_collection_categories_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )



from bungio.models.bungie.destiny.definitions.common import DestinyDisplayPropertiesDefinition
from bungio.models.bungie.destiny.definitions.common import DestinyIconSequenceDefinition
from bungio.models.bungie.destiny.definitions.common import DestinyPositionDefinition
from bungio.models.bungie.destiny.definitions.sockets import DestinySocketTypeDefinition
from bungio.models.bungie.destiny.definitions.sockets import DestinyInsertPlugActionDefinition
from bungio.models.bungie.destiny.definitions.sockets import DestinyPlugWhitelistEntryDefinition
from bungio.models.bungie.destiny.definitions.sockets import DestinySocketTypeScalarMaterialRequirementEntry
from bungio.models.bungie.destiny.definitions.sockets import DestinySocketCategoryDefinition
from bungio.models.bungie.destiny.definitions.sockets import DestinyPlugSetDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyItemTierTypeDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyItemTierTypeInfusionBlock
from bungio.models.bungie.destiny.definitions.items import DestinyDerivedItemCategoryDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyDerivedItemDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyItemPlugDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyPlugRuleDefinition
from bungio.models.bungie.destiny.definitions.items import DestinyParentItemOverride
from bungio.models.bungie.destiny.definitions.items import DestinyEnergyCapacityEntry
from bungio.models.bungie.destiny.definitions.items import DestinyEnergyCostEntry
from bungio.models.bungie.destiny.definitions.vendors import DestinyVendorLocationDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphNodeDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphNodeFeaturingStateDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphNodeActivityDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphNodeStateEntry
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphArtElementDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphConnectionDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphDisplayObjectiveDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyActivityGraphDisplayProgressionDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyLinkedGraphDefinition
from bungio.models.bungie.destiny.definitions.director import DestinyLinkedGraphEntryDefinition
from bungio.models.bungie.destiny.definitions.activitymodifiers import DestinyActivityModifierDefinition
from bungio.models.bungie.destiny.historicalstats.definitions import DestinyActivityModeType
from bungio.models.bungie.destiny.historicalstats.definitions import DestinyHistoricalStatsDefinition
from bungio.models.bungie.destiny.historicalstats.definitions import DestinyStatsGroupType
from bungio.models.bungie.destiny.historicalstats.definitions import DestinyStatsCategoryType
from bungio.models.bungie.destiny.historicalstats.definitions import UnitType
from bungio.models.bungie.destiny.historicalstats.definitions import DestinyStatsMergeMethod
from bungio.models.bungie.destiny.historicalstats.definitions import PeriodType
from bungio.models.bungie.destiny.definitions.artifacts import DestinyArtifactDefinition
from bungio.models.bungie.destiny.definitions.artifacts import DestinyArtifactTierDefinition
from bungio.models.bungie.destiny.definitions.artifacts import DestinyArtifactTierItemDefinition
from bungio.models.bungie.destiny.definitions.powercaps import DestinyPowerCapDefinition
from bungio.models.bungie.destiny.definitions.progression import DestinyProgressionLevelRequirementDefinition
from bungio.models.bungie.destiny.definitions.sources import DestinyItemSourceDefinition
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeBaseDefinition
from bungio.models.bungie.destiny.definitions.presentation import DestinyScoredPresentationNodeBaseDefinition
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeDefinition
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeChildrenBlock
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeChildEntryBase
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeChildEntry
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeCollectibleChildEntry
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeRequirementsBlock
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationChildBlock
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeRecordChildEntry
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeMetricChildEntry
from bungio.models.bungie.destiny.definitions.presentation import DestinyPresentationNodeCraftableChildEntry
from bungio.models.bungie.destiny.definitions.traits import DestinyTraitDefinition
from bungio.models.bungie.destiny.definitions.collectibles import DestinyCollectibleDefinition
from bungio.models.bungie.destiny.definitions.collectibles import DestinyCollectibleAcquisitionBlock
from bungio.models.bungie.destiny.definitions.collectibles import DestinyCollectibleStateBlock
from bungio.models.bungie.destiny.definitions.records import DestinyRecordDefinition
from bungio.models.bungie.destiny.definitions.records import DestinyRecordTitleBlock
from bungio.models.bungie.destiny.definitions.records import DestinyRecordCompletionBlock
from bungio.models.bungie.destiny.definitions.records import SchemaRecordStateBlock
from bungio.models.bungie.destiny.definitions.records import DestinyRecordExpirationBlock
from bungio.models.bungie.destiny.definitions.records import DestinyRecordIntervalBlock
from bungio.models.bungie.destiny.definitions.records import DestinyRecordIntervalObjective
from bungio.models.bungie.destiny.definitions.records import DestinyRecordIntervalRewards
from bungio.models.bungie.destiny.definitions.lore import DestinyLoreDefinition
from bungio.models.bungie.destiny.definitions.metrics import DestinyMetricDefinition
from bungio.models.bungie.destiny.definitions.energytypes import DestinyEnergyTypeDefinition
from bungio.models.bungie.destiny.definitions.animations import DestinyAnimationReference
from bungio.models.bungie.destiny.definitions.breakertypes import DestinyBreakerTypeDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinySeasonDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinySeasonActDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinySeasonPreviewDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinySeasonPreviewImageDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinySeasonPassDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinyEventCardDefinition
from bungio.models.bungie.destiny.definitions.seasons import DestinyEventCardImages
from bungio.models.bungie.tags.models.contracts import TagResponse
from bungio.models.bungie.destiny.components.inventory import DestinyPlatformSilverComponent
from bungio.models.bungie.destiny.components.inventory import DestinyCurrenciesComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemPerksComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemObjectivesComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemInstanceComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemInstanceEnergy
from bungio.models.bungie.destiny.entities.items import DestinyItemRenderComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemStatsComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemSocketsComponent
from bungio.models.bungie.destiny.entities.items import DestinyItemSocketState
from bungio.models.bungie.destiny.entities.items import DestinyItemTalentGridComponent
from bungio.models.bungie.destiny.entities.profiles import DestinyVendorReceiptsComponent
from bungio.models.bungie.destiny.entities.profiles import DestinyProfileComponent
from bungio.models.bungie.destiny.entities.inventory import DestinyInventoryComponent
from bungio.models.bungie.destiny.definitions.guardianranks import DestinyGuardianRankDefinition
from bungio.models.bungie.destiny.definitions.guardianranks import DestinyGuardianRankConstantsDefinition
from bungio.models.bungie.destiny.definitions.guardianranks import DestinyGuardianRankIconBackgroundsDefinition
from bungio.models.bungie.destiny.components.kiosks import DestinyKiosksComponent
from bungio.models.bungie.destiny.components.kiosks import DestinyKioskItem
from bungio.models.bungie.destiny.components.plugsets import DestinyPlugSetsComponent
from bungio.models.bungie.destiny.components.profiles import DestinyProfileProgressionComponent
from bungio.models.bungie.destiny.components.profiles import DestinyProfileTransitoryComponent
from bungio.models.bungie.destiny.components.profiles import DestinyProfileTransitoryPartyMember
from bungio.models.bungie.destiny.components.profiles import DestinyProfileTransitoryCurrentActivity
from bungio.models.bungie.destiny.components.profiles import DestinyProfileTransitoryJoinability
from bungio.models.bungie.destiny.components.profiles import DestinyProfileTransitoryTrackingEntry
from bungio.models.bungie.destiny.definitions.checklists import DestinyChecklistDefinition
from bungio.models.bungie.destiny.definitions.checklists import DestinyChecklistEntryDefinition
from bungio.models.bungie.destiny.components.presentation import DestinyPresentationNodesComponent
from bungio.models.bungie.destiny.components.presentation import DestinyPresentationNodeComponent
from bungio.models.bungie.destiny.components.records import DestinyRecordsComponent
from bungio.models.bungie.destiny.components.records import DestinyRecordComponent
from bungio.models.bungie.destiny.components.records import DestinyProfileRecordsComponent
from bungio.models.bungie.destiny.components.records import DestinyCharacterRecordsComponent
from bungio.models.bungie.destiny.components.collectibles import DestinyCollectiblesComponent
from bungio.models.bungie.destiny.components.collectibles import DestinyCollectibleComponent
from bungio.models.bungie.destiny.components.collectibles import DestinyProfileCollectiblesComponent
from bungio.models.bungie.destiny.components.metrics import DestinyMetricsComponent
from bungio.models.bungie.destiny.components.metrics import DestinyMetricComponent
from bungio.models.bungie.destiny.components.stringvariables import DestinyStringVariablesComponent
from bungio.models.bungie.destiny.components.social import DestinySocialCommendationsComponent
from bungio.models.bungie.destiny.definitions.social import DestinySocialCommendationNodeDefinition
from bungio.models.bungie.destiny.definitions.social import DestinySocialCommendationDefinition
from bungio.models.bungie.destiny.entities.characters import DestinyCharacterComponent
from bungio.models.bungie.destiny.entities.characters import DestinyCharacterProgressionComponent
from bungio.models.bungie.destiny.entities.characters import DestinyCharacterRenderComponent
from bungio.models.bungie.destiny.entities.characters import DestinyCharacterActivitiesComponent
from bungio.models.bungie.destiny.components.loadouts import DestinyLoadoutsComponent
from bungio.models.bungie.destiny.components.loadouts import DestinyLoadoutComponent
from bungio.models.bungie.destiny.components.loadouts import DestinyLoadoutItemComponent
from bungio.models.bungie.destiny.definitions.loadouts import DestinyLoadoutColorDefinition
from bungio.models.bungie.destiny.definitions.loadouts import DestinyLoadoutIconDefinition
from bungio.models.bungie.destiny.definitions.loadouts import DestinyLoadoutNameDefinition
from bungio.models.bungie.destiny.definitions.loadouts import DestinyLoadoutConstantsDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneDisplayPreference
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneType
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneQuestDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneQuestRewardsDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneQuestRewardItem
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneActivityDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneActivityVariantDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneRewardCategoryDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneRewardEntryDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneVendorDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneValueDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneChallengeActivityDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneChallengeDefinition
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneChallengeActivityGraphNodeEntry
from bungio.models.bungie.destiny.definitions.milestones import DestinyMilestoneChallengeActivityPhase
from bungio.models.bungie.destiny.components.craftables import DestinyCraftablesComponent
from bungio.models.bungie.destiny.components.craftables import DestinyCraftableComponent
from bungio.models.bungie.destiny.components.craftables import DestinyCraftableSocketComponent
from bungio.models.bungie.destiny.components.craftables import DestinyCraftableSocketPlugComponent
from bungio.models.bungie.destiny.components.items import DestinyItemReusablePlugsComponent
from bungio.models.bungie.destiny.components.items import DestinyItemPlugObjectivesComponent
from bungio.models.bungie.destiny.components.items import DestinyItemPlugComponent
from bungio.models.bungie.destiny.components.vendors import DestinyVendorGroupComponent
from bungio.models.bungie.destiny.components.vendors import DestinyVendorGroup
from bungio.models.bungie.destiny.components.vendors import DestinyVendorBaseComponent
from bungio.models.bungie.destiny.components.vendors import DestinyVendorSaleItemBaseComponent
from bungio.models.bungie.destiny.components.vendors import DestinyPublicVendorComponent
from bungio.models.bungie.destiny.components.vendors import DestinyPublicVendorSaleItemComponent
from bungio.models.bungie.destiny.entities.vendors import DestinyVendorComponent
from bungio.models.bungie.destiny.entities.vendors import DestinyVendorCategoriesComponent
from bungio.models.bungie.destiny.entities.vendors import DestinyVendorCategory
from bungio.models.bungie.destiny.entities.vendors import DestinyVendorSaleItemComponent
from bungio.models.bungie.destiny.requests.actions import DestinyActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyCharacterActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyItemActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyPostmasterTransferRequest
from bungio.models.bungie.destiny.requests.actions import DestinyItemSetActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyLoadoutActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyLoadoutUpdateActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyItemStateRequest
from bungio.models.bungie.destiny.requests.actions import DestinyInsertPlugsActionRequest
from bungio.models.bungie.destiny.requests.actions import DestinyInsertPlugsRequestEntry
from bungio.models.bungie.destiny.requests.actions import DestinySocketArrayType
from bungio.models.bungie.destiny.requests.actions import DestinyInsertPlugsFreeActionRequest
from bungio.models.bungie.destiny.reporting.requests import DestinyReportOffensePgcrRequest
from bungio.models.bungie.destiny.definitions.reporting import DestinyReportReasonCategoryDefinition
from bungio.models.bungie.destiny.definitions.reporting import DestinyReportReasonDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderActivityGraphDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyActivityGraphReference
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyActivityInteractableReference
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderActivitySetDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionCreatorSettings
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionSettingsControl
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionSearcherSettings
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionValues
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionValueDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderOptionGroupDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderLabelDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderLabelGroupDefinition
from bungio.models.bungie.destiny.definitions.fireteamfinder import DestinyFireteamFinderConstantsDefinition
from bungio.models.bungie.destiny.definitions.activities import DestinyActivityInteractableDefinition
from bungio.models.bungie.destiny.definitions.activities import DestinyActivityInteractableEntryDefinition
from bungio.models.bungie.user.models import GetCredentialTypesForAccountResponse
from bungio.models.bungie.content.models import ContentTypeDescription
from bungio.models.bungie.content.models import ContentTypeProperty
from bungio.models.bungie.content.models import ContentPropertyDataTypeEnum
from bungio.models.bungie.content.models import ContentTypeDefaultValue
from bungio.models.bungie.content.models import TagMetadataDefinition
from bungio.models.bungie.content.models import TagMetadataItem
from bungio.models.bungie.content.models import ContentPreview
from bungio.models.bungie.content.models import ContentTypePropertySection
from bungio.models.bungie.destiny.definitions import DestinyDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionDisplayPropertiesDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionStepDefinition
from bungio.models.bungie.destiny.definitions import DestinyInventoryItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemTooltipNotification
from bungio.models.bungie.destiny.definitions import DestinyItemActionBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemActionRequiredItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionRewardDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionMappingDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemCraftingBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemCraftingBlockBonusPlugDefinition
from bungio.models.bungie.destiny.definitions import DestinyMaterialRequirementSetDefinition
from bungio.models.bungie.destiny.definitions import DestinyMaterialRequirement
from bungio.models.bungie.destiny.definitions import DestinyItemInventoryBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyInventoryBucketDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSetBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSetBlockEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemStatBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyInventoryItemStatDefinition
from bungio.models.bungie.destiny.definitions import DestinyStatDefinition
from bungio.models.bungie.destiny.definitions import DestinyStatGroupDefinition
from bungio.models.bungie.destiny.definitions import DestinyStatDisplayDefinition
from bungio.models.bungie.destiny.definitions import DestinyStatOverrideDefinition
from bungio.models.bungie.destiny.definitions import DestinyEquippingBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyEquipmentSlotDefinition
from bungio.models.bungie.destiny.definitions import DestinyArtDyeReference
from bungio.models.bungie.destiny.definitions import DestinyItemTranslationBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyGearArtArrangementReference
from bungio.models.bungie.destiny.definitions import DestinyClassDefinition
from bungio.models.bungie.destiny.definitions import DestinyGenderDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorDisplayPropertiesDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorRequirementDisplayEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorActionDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorCategoryEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorCategoryOverlayDefinition
from bungio.models.bungie.destiny.definitions import DestinyDisplayCategoryDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorInteractionDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorInteractionReplyDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorInteractionSackEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorInventoryFlyoutDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorInventoryFlyoutBucketDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorItemQuantity
from bungio.models.bungie.destiny.definitions import DestinyItemCreationEntryLevelDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorSaleItemActionBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorItemSocketOverride
from bungio.models.bungie.destiny.definitions import DestinyVendorServiceDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorAcceptedItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyDestinationDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityGraphListEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityRewardDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityModifierReferenceDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityChallengeDefinition
from bungio.models.bungie.destiny.definitions import DestinyObjectiveDefinition
from bungio.models.bungie.destiny.definitions import DestinyObjectivePerkEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinySandboxPerkDefinition
from bungio.models.bungie.destiny.definitions import DestinyDamageTypeDefinition
from bungio.models.bungie.destiny.definitions import DestinyObjectiveStatEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemInvestmentStatDefinition
from bungio.models.bungie.destiny.definitions import DestinyLocationDefinition
from bungio.models.bungie.destiny.definitions import DestinyLocationReleaseDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityUnlockStringDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityRequirementsBlock
from bungio.models.bungie.destiny.definitions import DestinyActivityRequirementLabel
from bungio.models.bungie.destiny.definitions import DestinyActivityPlaylistItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityModeDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityMatchmakingBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityGuidedBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityLoadoutRequirementSet
from bungio.models.bungie.destiny.definitions import DestinyActivityLoadoutRequirement
from bungio.models.bungie.destiny.definitions import DestinyActivityInsertionPointDefinition
from bungio.models.bungie.destiny.definitions import DestinyPlaceDefinition
from bungio.models.bungie.destiny.definitions import DestinyActivityTypeDefinition
from bungio.models.bungie.destiny.definitions import DestinyUnlockExpressionDefinition
from bungio.models.bungie.destiny.definitions import DestinyDestinationBubbleSettingDefinition
from bungio.models.bungie.destiny.definitions import DestinyBubbleDefinition
from bungio.models.bungie.destiny.definitions import DestinyVendorGroupReference
from bungio.models.bungie.destiny.definitions import DestinyVendorGroupDefinition
from bungio.models.bungie.destiny.definitions import DestinyFactionDefinition
from bungio.models.bungie.destiny.definitions import DestinyFactionVendorDefinition
from bungio.models.bungie.destiny.definitions import DestinySandboxPatternDefinition
from bungio.models.bungie.destiny.definitions import DestinyArrangementRegionFilterDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemPreviewBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemQualityBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemVersionDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemValueBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSourceBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyRewardSourceDefinition
from bungio.models.bungie.destiny.definitions import DestinyRewardSourceCategory
from bungio.models.bungie.destiny.definitions import DestinyItemVendorSourceReference
from bungio.models.bungie.destiny.definitions import DestinyItemObjectiveBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyObjectiveDisplayProperties
from bungio.models.bungie.destiny.definitions import DestinyItemMetricBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyUnlockValueDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemGearsetBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSackBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSocketBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSocketEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSocketEntryPlugItemDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSocketEntryPlugItemRandomizedDefinition
from bungio.models.bungie.destiny.definitions import DestinyPlugItemCraftingRequirements
from bungio.models.bungie.destiny.definitions import DestinyPlugItemCraftingUnlockRequirement
from bungio.models.bungie.destiny.definitions import DestinyItemIntrinsicSocketEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSocketCategoryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemSummaryBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemTalentGridBlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyTalentGridDefinition
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeDefinition
from bungio.models.bungie.destiny.definitions import DestinyNodeActivationRequirement
from bungio.models.bungie.destiny.definitions import DestinyNodeStepDefinition
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepGroups
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepWeaponPerformances
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepImpactEffects
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepGuardianAttributes
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepLightAbilities
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeStepDamageTypes
from bungio.models.bungie.destiny.definitions import DestinyNodeSocketReplaceResponse
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeExclusiveSetDefinition
from bungio.models.bungie.destiny.definitions import DestinyTalentExclusiveGroup
from bungio.models.bungie.destiny.definitions import DestinyTalentNodeCategory
from bungio.models.bungie.destiny.definitions import DestinyItemPerkEntryDefinition
from bungio.models.bungie.destiny.definitions import DestinyItemCategoryDefinition
from bungio.models.bungie.destiny.definitions import DestinyProgressionRewardItemQuantity
from bungio.models.bungie.destiny.definitions import DestinyRaceDefinition
from bungio.models.bungie.destiny.definitions import DestinyUnlockDefinition
from bungio.models.bungie.destiny.definitions import DestinyMedalTierDefinition
from bungio.models.bungie.destiny.definitions import DestinyEntitySearchResult
from bungio.models.bungie.destiny.definitions import DestinyEntitySearchResultItem
from bungio.models.bungie.destiny.misc import DestinyColor
from bungio.models.bungie.destiny.constants import DestinyEnvironmentLocationMapping
from bungio.models.bungie.destiny.config import DestinyManifest
from bungio.models.bungie.destiny.config import GearAssetDataBaseDefinition
from bungio.models.bungie.destiny.config import ImagePyramidEntry
from bungio.models.bungie.destiny.responses import DestinyLinkedProfilesResponse
from bungio.models.bungie.destiny.responses import DestinyProfileUserInfoCard
from bungio.models.bungie.destiny.responses import DestinyErrorProfile
from bungio.models.bungie.destiny.responses import DestinyProfileResponse
from bungio.models.bungie.destiny.responses import DestinyCharacterResponse
from bungio.models.bungie.destiny.responses import DestinyItemResponse
from bungio.models.bungie.destiny.responses import DestinyVendorsResponse
from bungio.models.bungie.destiny.responses import PersonalDestinyVendorSaleItemSetComponent
from bungio.models.bungie.destiny.responses import DestinyVendorResponse
from bungio.models.bungie.destiny.responses import DestinyPublicVendorsResponse
from bungio.models.bungie.destiny.responses import PublicDestinyVendorSaleItemSetComponent
from bungio.models.bungie.destiny.responses import DestinyCollectibleNodeDetailResponse
from bungio.models.bungie.destiny.responses import InventoryChangedResponse
from bungio.models.bungie.destiny.responses import DestinyItemChangeResponse
from bungio.models.bungie.destiny.quests import DestinyObjectiveProgress
from bungio.models.bungie.destiny.quests import DestinyQuestStatus
from bungio.models.bungie.destiny.vendors import DestinyVendorReceipt
from bungio.models.bungie.destiny.sockets import DestinyItemPlugBase
from bungio.models.bungie.destiny.sockets import DestinyItemPlug
from bungio.models.bungie.destiny.artifacts import DestinyArtifactProfileScoped
from bungio.models.bungie.destiny.artifacts import DestinyArtifactCharacterScoped
from bungio.models.bungie.destiny.artifacts import DestinyArtifactTier
from bungio.models.bungie.destiny.artifacts import DestinyArtifactTierItem
from bungio.models.bungie.destiny.progression import DestinyFactionProgression
from bungio.models.bungie.destiny.milestones import DestinyMilestone
from bungio.models.bungie.destiny.milestones import DestinyMilestoneQuest
from bungio.models.bungie.destiny.milestones import DestinyMilestoneActivity
from bungio.models.bungie.destiny.milestones import DestinyMilestoneActivityVariant
from bungio.models.bungie.destiny.milestones import DestinyMilestoneActivityCompletionStatus
from bungio.models.bungie.destiny.milestones import DestinyMilestoneActivityPhase
from bungio.models.bungie.destiny.milestones import DestinyMilestoneChallengeActivity
from bungio.models.bungie.destiny.milestones import DestinyMilestoneVendor
from bungio.models.bungie.destiny.milestones import DestinyMilestoneRewardCategory
from bungio.models.bungie.destiny.milestones import DestinyMilestoneRewardEntry
from bungio.models.bungie.destiny.milestones import DestinyMilestoneContent
from bungio.models.bungie.destiny.milestones import DestinyMilestoneContentItemCategory
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestone
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneQuest
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneActivity
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneActivityVariant
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneChallenge
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneChallengeActivity
from bungio.models.bungie.destiny.milestones import DestinyPublicMilestoneVendor
from bungio.models.bungie.destiny.challenges import DestinyChallengeStatus
from bungio.models.bungie.destiny.perks import DestinyPerkReference
from bungio.models.bungie.destiny.character import DestinyCharacterCustomization
from bungio.models.bungie.destiny.character import DestinyCharacterPeerView
from bungio.models.bungie.destiny.character import DestinyItemPeerView
from bungio.models.bungie.config.clanbanner import ClanBannerDecal
from bungio.models.bungie.destiny.requests import DestinyItemTransferRequest
from bungio.models.bungie.destiny.historicalstats import DestinyPostGameCarnageReportData
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsActivity
from bungio.models.bungie.destiny.historicalstats import DestinyPostGameCarnageReportEntry
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsValue
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsValuePair
from bungio.models.bungie.destiny.historicalstats import DestinyPlayer
from bungio.models.bungie.destiny.historicalstats import DestinyPostGameCarnageReportExtendedData
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalWeaponStats
from bungio.models.bungie.destiny.historicalstats import DestinyPostGameCarnageReportTeamEntry
from bungio.models.bungie.destiny.historicalstats import DestinyLeaderboard
from bungio.models.bungie.destiny.historicalstats import DestinyLeaderboardEntry
from bungio.models.bungie.destiny.historicalstats import DestinyLeaderboardResults
from bungio.models.bungie.destiny.historicalstats import DestinyClanAggregateStat
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsByPeriod
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsAccountResult
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsWithMerged
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalStatsPerCharacter
from bungio.models.bungie.destiny.historicalstats import DestinyActivityHistoryResults
from bungio.models.bungie.destiny.historicalstats import DestinyHistoricalWeaponStatsData
from bungio.models.bungie.destiny.historicalstats import DestinyAggregateActivityResults
from bungio.models.bungie.destiny.historicalstats import DestinyAggregateActivityStats
from bungio.models.bungie.destiny.advanced import AwaInitializeResponse
from bungio.models.bungie.destiny.advanced import AwaPermissionRequested
from bungio.models.bungie.destiny.advanced import AwaType
from bungio.models.bungie.destiny.advanced import AwaUserResponse
from bungio.models.bungie.destiny.advanced import AwaUserSelection
from bungio.models.bungie.destiny.advanced import AwaAuthorizationResult
from bungio.models.bungie.destiny.advanced import AwaResponseReason
from bungio.models.bungie.destiny.activities import DestinyPublicActivityStatus
from bungio.models.bungie.social.friends import BungieFriendListResponse
from bungio.models.bungie.social.friends import BungieFriend
from bungio.models.bungie.social.friends import PresenceStatus
from bungio.models.bungie.social.friends import PresenceOnlineStateFlags
from bungio.models.bungie.social.friends import FriendRelationshipState
from bungio.models.bungie.social.friends import BungieFriendRequestListResponse
from bungio.models.bungie.social.friends import PlatformFriendType
from bungio.models.bungie.social.friends import PlatformFriendResponse
from bungio.models.bungie.social.friends import PlatformFriend
from bungio.models.bungie.common.models import CoreSettingsConfiguration
from bungio.models.bungie.common.models import CoreSystem
from bungio.models.bungie.common.models import CoreSetting
from bungio.models.bungie.common.models import Destiny2CoreSettings
from bungio.models.bungie.applications import ApplicationScopes
from bungio.models.bungie.applications import ApiUsage
from bungio.models.bungie.applications import Series
from bungio.models.bungie.applications import Datapoint
from bungio.models.bungie.applications import Application
from bungio.models.bungie.applications import OAuthApplicationType
from bungio.models.bungie.applications import ApplicationStatus
from bungio.models.bungie.applications import ApplicationDeveloper
from bungio.models.bungie.applications import DeveloperRole
from bungio.models.bungie.user import UserMembership
from bungio.models.bungie.user import CrossSaveUserMembership
from bungio.models.bungie.user import UserInfoCard
from bungio.models.bungie.user import GeneralUser
from bungio.models.bungie.user import UserToUserContext
from bungio.models.bungie.user import UserMembershipData
from bungio.models.bungie.user import HardLinkedUserMembership
from bungio.models.bungie.user import UserSearchResponse
from bungio.models.bungie.user import UserSearchResponseDetail
from bungio.models.bungie.user import UserSearchPrefixRequest
from bungio.models.bungie.user import ExactSearchRequest
from bungio.models.bungie.user import EmailSettings
from bungio.models.bungie.user import EmailOptInDefinition
from bungio.models.bungie.user import OptInFlags
from bungio.models.bungie.user import EmailSubscriptionDefinition
from bungio.models.bungie.user import EMailSettingLocalization
from bungio.models.bungie.user import EMailSettingSubscriptionLocalization
from bungio.models.bungie.user import EmailViewDefinition
from bungio.models.bungie.user import EmailViewDefinitionSetting
from bungio.models.bungie.misc import BungieMembershipType
from bungio.models.bungie.misc import BungieCredentialType
from bungio.models.bungie.misc import SearchResultOfContentItemPublicContract
from bungio.models.bungie.misc import SearchResultOfPostResponse
from bungio.models.bungie.misc import SearchResultOfGroupV2Card
from bungio.models.bungie.misc import SearchResultOfGroupMember
from bungio.models.bungie.misc import SearchResultOfGroupBan
from bungio.models.bungie.misc import SearchResultOfGroupEditHistory
from bungio.models.bungie.misc import SearchResultOfGroupMemberApplication
from bungio.models.bungie.misc import SearchResultOfGroupMembership
from bungio.models.bungie.misc import SearchResultOfGroupPotentialMembership
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyVendorReceiptsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyInventoryComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyProfileComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyPlatformSilverComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyKiosksComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyPlugSetsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyProfileProgressionComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyPresentationNodesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyProfileRecordsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyProfileCollectiblesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyProfileTransitoryComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyMetricsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyStringVariablesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinySocialCommendationsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCharacterComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyInventoryComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyLoadoutsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCharacterProgressionComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCharacterRenderComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCharacterActivitiesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyKiosksComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyPlugSetsComponent
from bungio.models.bungie.misc import DestinyBaseItemComponentSetOfuint32
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemPerksComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyPresentationNodesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCharacterRecordsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCollectiblesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyStringVariablesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCraftablesComponent
from bungio.models.bungie.misc import DestinyBaseItemComponentSetOfint64
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemPerksComponent
from bungio.models.bungie.misc import DestinyItemComponentSetOfint64
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemInstanceComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemRenderComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemStatsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemSocketsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemReusablePlugsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemPlugObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyItemTalentGridComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemPlugComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint64AndDestinyCurrenciesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCharacterComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCharacterProgressionComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCharacterRenderComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCharacterActivitiesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyLoadoutsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCharacterRecordsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCollectiblesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyCurrenciesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemInstanceComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemObjectivesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemPerksComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemRenderComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemStatsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemTalentGridComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemSocketsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemReusablePlugsComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyItemPlugObjectivesComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyVendorGroupComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyVendorComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyVendorCategoriesComponent
from bungio.models.bungie.misc import DestinyVendorSaleItemSetComponentOfDestinyVendorSaleItemComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndPersonalDestinyVendorSaleItemSetComponent
from bungio.models.bungie.misc import DestinyBaseItemComponentSetOfint32
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemPerksComponent
from bungio.models.bungie.misc import DestinyItemComponentSetOfint32
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemInstanceComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemRenderComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemStatsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemSocketsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemReusablePlugsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemPlugObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyItemTalentGridComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyVendorComponent
from bungio.models.bungie.misc import SingleComponentResponseOfDestinyVendorCategoriesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfint32AndDestinyVendorSaleItemComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyPublicVendorComponent
from bungio.models.bungie.misc import DestinyVendorSaleItemSetComponentOfDestinyPublicVendorSaleItemComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndPublicDestinyVendorSaleItemSetComponent
from bungio.models.bungie.misc import DestinyItemComponentSetOfuint32
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemInstanceComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemRenderComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemStatsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemSocketsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemReusablePlugsComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemPlugObjectivesComponent
from bungio.models.bungie.misc import DictionaryComponentResponseOfuint32AndDestinyItemTalentGridComponent
from bungio.models.bungie.misc import SearchResultOfDestinyEntitySearchResultItem
from bungio.models.bungie.misc import SearchResultOfTrendingEntry
from bungio.models.bungie.misc import SearchResultOfFireteamSummary
from bungio.models.bungie.misc import SearchResultOfFireteamResponse
from bungio.models.bungie.misc import GlobalAlert
from bungio.models.bungie.misc import GlobalAlertLevel
from bungio.models.bungie.misc import GlobalAlertType
from bungio.models.bungie.misc import StreamInfo
from bungio.models.bungie.ignores import IgnoreResponse
from bungio.models.bungie.ignores import IgnoreStatus
from bungio.models.bungie.ignores import IgnoreLength
from bungio.models.bungie.config import UserTheme
from bungio.models.bungie.config import GroupTheme
from bungio.models.bungie.groupsv2 import GroupUserInfoCard
from bungio.models.bungie.groupsv2 import GroupResponse
from bungio.models.bungie.groupsv2 import GroupV2
from bungio.models.bungie.groupsv2 import GroupType
from bungio.models.bungie.groupsv2 import ChatSecuritySetting
from bungio.models.bungie.groupsv2 import GroupHomepage
from bungio.models.bungie.groupsv2 import MembershipOption
from bungio.models.bungie.groupsv2 import GroupPostPublicity
from bungio.models.bungie.groupsv2 import GroupFeatures
from bungio.models.bungie.groupsv2 import Capabilities
from bungio.models.bungie.groupsv2 import HostGuidedGamesPermissionLevel
from bungio.models.bungie.groupsv2 import RuntimeGroupMemberType
from bungio.models.bungie.groupsv2 import GroupV2ClanInfo
from bungio.models.bungie.groupsv2 import ClanBanner
from bungio.models.bungie.groupsv2 import GroupV2ClanInfoAndInvestment
from bungio.models.bungie.groupsv2 import GroupUserBase
from bungio.models.bungie.groupsv2 import GroupMember
from bungio.models.bungie.groupsv2 import GroupAllianceStatus
from bungio.models.bungie.groupsv2 import GroupPotentialMember
from bungio.models.bungie.groupsv2 import GroupPotentialMemberStatus
from bungio.models.bungie.groupsv2 import GroupDateRange
from bungio.models.bungie.groupsv2 import GroupV2Card
from bungio.models.bungie.groupsv2 import GroupSearchResponse
from bungio.models.bungie.groupsv2 import GroupSortBy
from bungio.models.bungie.groupsv2 import GroupMemberCountFilter
from bungio.models.bungie.groupsv2 import GroupNameSearchRequest
from bungio.models.bungie.groupsv2 import GroupOptionalConversation
from bungio.models.bungie.groupsv2 import GroupEditAction
from bungio.models.bungie.groupsv2 import GroupOptionsEditAction
from bungio.models.bungie.groupsv2 import GroupOptionalConversationAddRequest
from bungio.models.bungie.groupsv2 import GroupOptionalConversationEditRequest
from bungio.models.bungie.groupsv2 import GroupMemberLeaveResult
from bungio.models.bungie.groupsv2 import GroupBanRequest
from bungio.models.bungie.groupsv2 import GroupBan
from bungio.models.bungie.groupsv2 import GroupEditHistory
from bungio.models.bungie.groupsv2 import GroupMemberApplication
from bungio.models.bungie.groupsv2 import GroupApplicationResolveState
from bungio.models.bungie.groupsv2 import GroupApplicationRequest
from bungio.models.bungie.groupsv2 import GroupApplicationListRequest
from bungio.models.bungie.groupsv2 import GroupsForMemberFilter
from bungio.models.bungie.groupsv2 import GroupMembershipBase
from bungio.models.bungie.groupsv2 import GroupMembership
from bungio.models.bungie.groupsv2 import GroupMembershipSearchResponse
from bungio.models.bungie.groupsv2 import GetGroupsForMemberResponse
from bungio.models.bungie.groupsv2 import GroupPotentialMembership
from bungio.models.bungie.groupsv2 import GroupPotentialMembershipSearchResponse
from bungio.models.bungie.groupsv2 import GroupApplicationResponse
from bungio.models.bungie.content import ContentItemPublicContract
from bungio.models.bungie.content import ContentRepresentation
from bungio.models.bungie.content import CommentSummary
from bungio.models.bungie.content import NewsArticleRssResponse
from bungio.models.bungie.content import NewsArticleRssItem
from bungio.models.bungie.queries import SearchResult
from bungio.models.bungie.queries import PagedQuery
from bungio.models.bungie.forum import ForumTopicsCategoryFiltersEnum
from bungio.models.bungie.forum import ForumTopicsQuickDateEnum
from bungio.models.bungie.forum import ForumTopicsSortEnum
from bungio.models.bungie.forum import PostResponse
from bungio.models.bungie.forum import ForumMediaType
from bungio.models.bungie.forum import ForumPostPopularity
from bungio.models.bungie.forum import PostSearchResponse
from bungio.models.bungie.forum import PollResponse
from bungio.models.bungie.forum import PollResult
from bungio.models.bungie.forum import ForumRecruitmentDetail
from bungio.models.bungie.forum import ForumRecruitmentIntensityLabel
from bungio.models.bungie.forum import ForumRecruitmentToneLabel
from bungio.models.bungie.forum import ForumPostSortEnum
from bungio.models.bungie.forum import CommunityContentSortMode
from bungio.models.bungie.forums import ForumPostCategoryEnums
from bungio.models.bungie.forums import ForumFlagsEnum
from bungio.models.bungie.destiny import DestinyProgression
from bungio.models.bungie.destiny import DestinyProgressionResetEntry
from bungio.models.bungie.destiny import DestinyProgressionRewardItemState
from bungio.models.bungie.destiny import DestinyProgressionScope
from bungio.models.bungie.destiny import DestinyProgressionStepDisplayEffect
from bungio.models.bungie.destiny import DestinyItemQuantity
from bungio.models.bungie.destiny import SocketTypeActionType
from bungio.models.bungie.destiny import DestinySocketVisibility
from bungio.models.bungie.destiny import DestinySocketCategoryStyle
from bungio.models.bungie.destiny import TierType
from bungio.models.bungie.destiny import BucketScope
from bungio.models.bungie.destiny import BucketCategory
from bungio.models.bungie.destiny import ItemLocation
from bungio.models.bungie.destiny import DestinyStatAggregationType
from bungio.models.bungie.destiny import DestinyStatCategory
from bungio.models.bungie.destiny import EquippingItemBlockAttributes
from bungio.models.bungie.destiny import DestinyAmmunitionType
from bungio.models.bungie.destiny import DyeReference
from bungio.models.bungie.destiny import DestinyClass
from bungio.models.bungie.destiny import DestinyGender
from bungio.models.bungie.destiny import DestinyVendorProgressionType
from bungio.models.bungie.destiny import VendorDisplayCategorySortOrder
from bungio.models.bungie.destiny import DestinyVendorInteractionRewardSelection
from bungio.models.bungie.destiny import DestinyVendorReplyType
from bungio.models.bungie.destiny import VendorInteractionType
from bungio.models.bungie.destiny import DestinyItemSortType
from bungio.models.bungie.destiny import DestinyVendorItemRefundPolicy
from bungio.models.bungie.destiny import DestinyGatingScope
from bungio.models.bungie.destiny import ActivityGraphNodeHighlightType
from bungio.models.bungie.destiny import DestinyUnlockValueUIStyle
from bungio.models.bungie.destiny import DestinyObjectiveGrantStyle
from bungio.models.bungie.destiny import DamageType
from bungio.models.bungie.destiny import DestinyObjectiveUiStyle
from bungio.models.bungie.destiny import DestinyActivityNavPointType
from bungio.models.bungie.destiny import DestinyActivityModeCategory
from bungio.models.bungie.destiny import DestinyItemSubType
from bungio.models.bungie.destiny import DestinyGraphNodeState
from bungio.models.bungie.destiny import DestinyPresentationNodeType
from bungio.models.bungie.destiny import DestinyScope
from bungio.models.bungie.destiny import DestinyPresentationDisplayStyle
from bungio.models.bungie.destiny import DestinyRecordValueStyle
from bungio.models.bungie.destiny import DestinyRecordToastStyle
from bungio.models.bungie.destiny import DestinyPresentationScreenStyle
from bungio.models.bungie.destiny import PlugUiStyles
from bungio.models.bungie.destiny import PlugAvailabilityMode
from bungio.models.bungie.destiny import DestinyEnergyType
from bungio.models.bungie.destiny import SocketPlugSources
from bungio.models.bungie.destiny import ItemPerkVisibility
from bungio.models.bungie.destiny import SpecialItemType
from bungio.models.bungie.destiny import DestinyItemType
from bungio.models.bungie.destiny import DestinyBreakerType
from bungio.models.bungie.destiny import DestinyProgressionRewardItemAcquisitionBehavior
from bungio.models.bungie.destiny import ItemBindStatus
from bungio.models.bungie.destiny import TransferStatuses
from bungio.models.bungie.destiny import ItemState
from bungio.models.bungie.destiny import DestinyGameVersions
from bungio.models.bungie.destiny import DestinyComponentType
from bungio.models.bungie.destiny import DestinyPresentationNodeState
from bungio.models.bungie.destiny import DestinyRecordState
from bungio.models.bungie.destiny import DestinyCollectibleState
from bungio.models.bungie.destiny import DestinyPartyMemberStates
from bungio.models.bungie.destiny import DestinyGamePrivacySetting
from bungio.models.bungie.destiny import DestinyJoinClosedReasons
from bungio.models.bungie.destiny import DestinyRace
from bungio.models.bungie.destiny import DestinyActivity
from bungio.models.bungie.destiny import DestinyActivityDifficultyTier
from bungio.models.bungie.destiny import DestinyStat
from bungio.models.bungie.destiny import EquipFailureReason
from bungio.models.bungie.destiny import DestinyTalentNode
from bungio.models.bungie.destiny import DestinyTalentNodeState
from bungio.models.bungie.destiny import DestinyTalentNodeStatBlock
from bungio.models.bungie.destiny import DestinyVendorFilter
from bungio.models.bungie.destiny import VendorItemStatus
from bungio.models.bungie.destiny import DestinyUnlockStatus
from bungio.models.bungie.destiny import DestinyVendorItemState
from bungio.models.bungie.destiny import DestinyEquipItemResults
from bungio.models.bungie.destiny import DestinyEquipItemResult
from bungio.models.bungie.destiny import FireteamFinderCodeOptionType
from bungio.models.bungie.destiny import FireteamFinderOptionAvailability
from bungio.models.bungie.destiny import FireteamFinderOptionVisibility
from bungio.models.bungie.destiny import FireteamFinderOptionControlType
from bungio.models.bungie.destiny import FireteamFinderOptionSearchFilterType
from bungio.models.bungie.destiny import FireteamFinderOptionDisplayFormat
from bungio.models.bungie.destiny import FireteamFinderOptionValueProviderType
from bungio.models.bungie.destiny import FireteamFinderOptionValueFlags
from bungio.models.bungie.destiny import FireteamFinderLabelFieldType
from bungio.models.bungie.interpolation import InterpolationPoint
from bungio.models.bungie.interpolation import InterpolationPointFloat
from bungio.models.bungie.dates import DateRange
from bungio.models.bungie.links import HyperlinkReference
from bungio.models.bungie.entities import EntityActionResult
from bungio.models.bungie.exceptions import PlatformErrorCodes
from bungio.models.bungie.tokens import PartnerOfferClaimRequest
from bungio.models.bungie.tokens import PartnerOfferSkuHistoryResponse
from bungio.models.bungie.tokens import PartnerOfferHistoryResponse
from bungio.models.bungie.tokens import PartnerRewardHistoryResponse
from bungio.models.bungie.tokens import TwitchDropHistoryResponse
from bungio.models.bungie.tokens import BungieRewardDisplay
from bungio.models.bungie.tokens import UserRewardAvailabilityModel
from bungio.models.bungie.tokens import RewardAvailabilityModel
from bungio.models.bungie.tokens import CollectibleDefinitions
from bungio.models.bungie.tokens import RewardDisplayProperties
from bungio.models.bungie.streaming import DropStateEnum
from bungio.models.bungie.components import ComponentResponse
from bungio.models.bungie.components import ComponentPrivacySetting
from bungio.models.bungie.trending import TrendingCategories
from bungio.models.bungie.trending import TrendingCategory
from bungio.models.bungie.trending import TrendingEntry
from bungio.models.bungie.trending import TrendingEntryType
from bungio.models.bungie.trending import TrendingDetail
from bungio.models.bungie.trending import TrendingEntryNews
from bungio.models.bungie.trending import TrendingEntrySupportArticle
from bungio.models.bungie.trending import TrendingEntryDestinyItem
from bungio.models.bungie.trending import TrendingEntryDestinyActivity
from bungio.models.bungie.trending import TrendingEntryDestinyRitual
from bungio.models.bungie.trending import TrendingEntryCommunityCreation
from bungio.models.bungie.fireteam import FireteamDateRange
from bungio.models.bungie.fireteam import FireteamPlatform
from bungio.models.bungie.fireteam import FireteamPublicSearchOption
from bungio.models.bungie.fireteam import FireteamSlotSearch
from bungio.models.bungie.fireteam import FireteamSummary
from bungio.models.bungie.fireteam import FireteamResponse
from bungio.models.bungie.fireteam import FireteamMember
from bungio.models.bungie.fireteam import FireteamUserInfoCard
from bungio.models.bungie.fireteam import FireteamPlatformInviteResult
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderApplicationType
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderApplyToListingResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderApplication
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderApplicationState
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderPlayerId
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderApplicantSet
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListing
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbySettings
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbyPrivacyScope
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListingValue
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbyState
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderBulkGetListingStatusResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListingStatus
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbyListingReference
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetApplicationResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetListingApplicationsResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbyResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderLobbyPlayer
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderPlayerReadinessState
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetPlayerLobbiesResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetPlayerApplicationsResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetPlayerOffersResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderOffer
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderOfferState
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetCharacterActivityAccessResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderActivityGraphState
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderGetLobbyOffersResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderHostLobbyResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderHostLobbyRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderJoinLobbyRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderKickPlayerRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToApplicationResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToApplicationRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToAuthenticationResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToAuthenticationRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToOfferResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderRespondToOfferRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderSearchListingsByClanResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderSearchListingsByClanRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderSearchListingsByFiltersResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderSearchListingsByFiltersRequest
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListingFilter
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListingFilterRangeType
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderListingFilterMatchType
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderUpdateLobbySettingsResponse
from bungio.models.bungie.fireteamfinder import DestinyFireteamFinderUpdateLobbySettingsRequest



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, BaseEnum, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import BungieMembershipType
    from bungio.models import DestinyInventoryItemDefinition


@custom_define()
class DestinyActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        membership_type: _No description given by bungie._
    """

    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))


@custom_define()
class DestinyCharacterActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        membership_type: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))


@custom_define()
class DestinyItemActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        item_id: The instance ID of the item for this action request.
        membership_type: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    item_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))


@custom_define()
class DestinyPostmasterTransferRequest(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        character_id: _No description given by bungie._
        item_id: The instance ID of the item for this action request.
        item_reference_hash: _No description given by bungie._
        membership_type: _No description given by bungie._
        stack_size: _No description given by bungie._
        manifest_item_reference_hash: Manifest information for `item_reference_hash`
    """

    character_id: int = custom_field(metadata={"int64": True})
    item_id: int = custom_field(metadata={"int64": True})
    item_reference_hash: int = custom_field()
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    stack_size: int = custom_field()
    manifest_item_reference_hash: Optional["DestinyInventoryItemDefinition"] = custom_field(default=None)


@custom_define()
class DestinyItemSetActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        item_ids: _No description given by bungie._
        membership_type: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    item_ids: list[int] = custom_field(metadata={"type": """list[int]"""})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))


@custom_define()
class DestinyLoadoutActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        loadout_index: The index of the loadout for this action request.
        membership_type: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    loadout_index: int = custom_field()
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))


@custom_define()
class DestinyLoadoutUpdateActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        color_hash: _No description given by bungie._
        icon_hash: _No description given by bungie._
        loadout_index: The index of the loadout for this action request.
        membership_type: _No description given by bungie._
        name_hash: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    color_hash: int = custom_field()
    icon_hash: int = custom_field()
    loadout_index: int = custom_field()
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    name_hash: int = custom_field()


@custom_define()
class DestinyItemStateRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        item_id: The instance ID of the item for this action request.
        membership_type: _No description given by bungie._
        state: _No description given by bungie._
    """

    character_id: int = custom_field(metadata={"int64": True})
    item_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    state: bool = custom_field()


@custom_define()
class DestinyInsertPlugsActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        action_token: Action token provided by the AwaGetActionToken API call.
        character_id: _No description given by bungie._
        item_instance_id: The instance ID of the item having a plug inserted. Only instanced items can have sockets.
        membership_type: _No description given by bungie._
        plug: The plugs being inserted.
    """

    action_token: str = custom_field()
    character_id: int = custom_field(metadata={"int64": True})
    item_instance_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    plug: "DestinyInsertPlugsRequestEntry" = custom_field()


@custom_define()
class DestinyInsertPlugsRequestEntry(BaseModel):
    """
    Represents all of the data related to a single plug to be inserted. Note that, while you *can* point to a socket that represents infusion, you will receive an error if you attempt to do so. Come on guys, let's play nice.

    None
    Attributes:
        plug_item_hash: Plugs are never instanced (except in infusion). So with the hash alone, we should be able to: 1) Infer whether the player actually needs to have the item, or if it's a reusable plug 2) Perform any operation needed to use the Plug, including removing the plug item and running reward sheets.
        socket_array_type: This property, combined with the socketIndex, tells us which socket we are referring to (since operations can be performed on both Intrinsic and "default" sockets, and they occupy different arrays in the Inventory Item Definition). I know, I know. Don't give me that look.
        socket_index: The index into the socket array, which identifies the specific socket being operated on. We also need to know the socketArrayType in order to uniquely identify the socket. Don't point to or try to insert a plug into an infusion socket. It won't work.
    """

    plug_item_hash: int = custom_field()
    socket_array_type: Union["DestinySocketArrayType", int] = custom_field(
        converter=enum_converter("DestinySocketArrayType")
    )
    socket_index: int = custom_field()


class DestinySocketArrayType(BaseEnum):
    """
    If you look in the DestinyInventoryItemDefinition's "sockets" property, you'll see that there are two types of sockets: intrinsic, and "socketEntry." Unfortunately, because Intrinsic sockets are a whole separate array, it is no longer sufficient to know the index into that array to know which socket we're talking about. You have to know whether it's in the default "socketEntries" or if it's in the "intrinsic" list.
    """

    DEFAULT = 0
    """_No description given by bungie._ """
    INTRINSIC = 1
    """_No description given by bungie._ """


@custom_define()
class DestinyInsertPlugsFreeActionRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        character_id: _No description given by bungie._
        item_id: The instance ID of the item for this action request.
        membership_type: _No description given by bungie._
        plug: The plugs being inserted.
    """

    character_id: int = custom_field(metadata={"int64": True})
    item_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    plug: "DestinyInsertPlugsRequestEntry" = custom_field()



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, HashObject, ManifestModel, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import DestinySocketVisibility
    from bungio.models import DestinyInventoryItemDefinition
    from bungio.models import DestinySocketCategoryStyle
    from bungio.models import SocketTypeActionType
    from bungio.models import DestinyDisplayPropertiesDefinition
    from bungio.models import DestinyItemSocketEntryPlugItemRandomizedDefinition


@custom_define()
class DestinySocketTypeDefinition(ManifestModel, HashObject):
    """
    All Sockets have a "Type": a set of common properties that determine when the socket allows Plugs to be inserted, what Categories of Plugs can be inserted, and whether the socket is even visible at all given the current game/character/account state. See DestinyInventoryItemDefinition for more information about Socketed items and Plugs.

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        always_randomize_sockets: _No description given by bungie._
        avoid_duplicates_on_initialization: _No description given by bungie._
        currency_scalars: _No description given by bungie._
        display_properties: There are fields for this display data, but they appear to be unpopulated as of now. I am not sure where in the UI these would show if they even were populated, but I will continue to return this data in case it becomes useful.
        hash: The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
        hide_duplicate_reusable_plugs: _No description given by bungie._
        index: The index of the entity as it was found in the investment tables.
        insert_action: Defines what happens when a plug is inserted into sockets of this type.
        is_preview_enabled: _No description given by bungie._
        overrides_ui_appearance: This property indicates if the socket type determines whether Emblem icons and nameplates should be overridden by the inserted plug item's icon and nameplate.
        plug_whitelist: A list of Plug "Categories" that are allowed to be plugged into sockets of this type. These should be compared against a given plug item's DestinyInventoryItemDefinition.plug.plugCategoryHash, which indicates the plug item's category. If the plug's category matches any whitelisted plug, or if the whitelist is empty, it is allowed to be inserted.
        redacted: If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
        socket_category_hash: _No description given by bungie._
        visibility: Sometimes a socket isn't visible. These are some of the conditions under which sockets of this type are not visible. Unfortunately, the truth of visibility is much, much more complex. Best to rely on the live data for whether the socket is visible and enabled.
        manifest_socket_category_hash: Manifest information for `socket_category_hash`
    """

    always_randomize_sockets: bool = custom_field()
    avoid_duplicates_on_initialization: bool = custom_field()
    currency_scalars: list["DestinySocketTypeScalarMaterialRequirementEntry"] = custom_field(
        metadata={"type": """list[DestinySocketTypeScalarMaterialRequirementEntry]"""}
    )
    display_properties: "DestinyDisplayPropertiesDefinition" = custom_field()
    hide_duplicate_reusable_plugs: bool = custom_field()
    index: int = custom_field()
    insert_action: "DestinyInsertPlugActionDefinition" = custom_field()
    is_preview_enabled: bool = custom_field()
    overrides_ui_appearance: bool = custom_field()
    plug_whitelist: list["DestinyPlugWhitelistEntryDefinition"] = custom_field(
        metadata={"type": """list[DestinyPlugWhitelistEntryDefinition]"""}
    )
    redacted: bool = custom_field()
    socket_category_hash: int = custom_field()
    visibility: Union["DestinySocketVisibility", int] = custom_field(
        converter=enum_converter("DestinySocketVisibility")
    )
    manifest_socket_category_hash: Optional["DestinySocketCategoryDefinition"] = custom_field(default=None)


@custom_define()
class DestinyInsertPlugActionDefinition(BaseModel):
    """
    Data related to what happens while a plug is being inserted, mostly for UI purposes.

    None
    Attributes:
        action_execute_seconds: How long it takes for the Plugging of the item to be completed once it is initiated, if you care.
        action_type: The type of action being performed when you act on this Socket Type. The most common value is "insert plug", but there are others as well (for instance, a "Masterwork" socket may allow for Re-initialization, and an Infusion socket allows for items to be consumed to upgrade the item)
    """

    action_execute_seconds: int = custom_field()
    action_type: Union["SocketTypeActionType", int] = custom_field(converter=enum_converter("SocketTypeActionType"))


@custom_define()
class DestinyPlugWhitelistEntryDefinition(BaseModel):
    """
    Defines a plug "Category" that is allowed to be plugged into a socket of this type. This should be compared against a given plug item's DestinyInventoryItemDefinition.plug.plugCategoryHash, which indicates the plug item's category.

    None
    Attributes:
        category_hash: The hash identifier of the Plug Category to compare against the plug item's plug.plugCategoryHash. Note that this does NOT relate to any Definition in itself, it is only used for comparison purposes.
        category_identifier: The string identifier for the category, which is here mostly for debug purposes.
        reinitialization_possible_plug_hashes: The list of all plug items (DestinyInventoryItemDefinition) that the socket may randomly be populated with when reinitialized. Which ones you should actually show are determined by the plug being inserted into the socket, and the socket’s type. When you inspect the plug that could go into a Masterwork Socket, look up the socket type of the socket being inspected and find the DestinySocketTypeDefinition. Then, look at the Plugs that can fit in that socket. Find the Whitelist in the DestinySocketTypeDefinition that matches the plug item’s categoryhash. That whitelist entry will potentially have a new “reinitializationPossiblePlugHashes” property.If it does, that means we know what it will roll if you try to insert this plug into this socket.
    """

    category_hash: int = custom_field()
    category_identifier: str = custom_field()
    reinitialization_possible_plug_hashes: list[int] = custom_field(metadata={"type": """list[int]"""})


@custom_define()
class DestinySocketTypeScalarMaterialRequirementEntry(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        currency_item_hash: _No description given by bungie._
        scalar_value: _No description given by bungie._
        manifest_currency_item_hash: Manifest information for `currency_item_hash`
    """

    currency_item_hash: int = custom_field()
    scalar_value: int = custom_field()
    manifest_currency_item_hash: Optional["DestinyInventoryItemDefinition"] = custom_field(default=None)


@custom_define()
class DestinySocketCategoryDefinition(ManifestModel, HashObject):
    """
    Sockets on an item are organized into Categories visually. You can find references to the socket category defined on an item's DestinyInventoryItemDefinition.sockets.socketCategories property. This has the display information for rendering the categories' header, and a hint for how the UI should handle showing this category. The shitty thing about this, however, is that the socket categories' UI style can be overridden by the item's UI style. For instance, the Socket Category used by Emote Sockets says it's "consumable," but that's a lie: they're all reusable, and overridden by the detail UI pages in ways that we can't easily account for in the API. As a result, I will try to compile these rules into the individual sockets on items, and provide the best hint possible there through the plugSources property. In the future, I may attempt to use this information in conjunction with the item to provide a more usable UI hint on the socket layer, but for now improving the consistency of plugSources is the best I have time to provide. (See https://github.com/Bungie-net/api/issues/522 for more info)

    None
    Attributes:
        category_style: Same as uiCategoryStyle, but in a more usable enumeration form.
        display_properties: _No description given by bungie._
        hash: The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
        index: The index of the entity as it was found in the investment tables.
        redacted: If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
        ui_category_style: A string hinting to the game's UI system about how the sockets in this category should be displayed. BNet doesn't use it: it's up to you to find valid values and make your own special UI if you want to honor this category style.
    """

    category_style: Union["DestinySocketCategoryStyle", int] = custom_field(
        converter=enum_converter("DestinySocketCategoryStyle")
    )
    display_properties: "DestinyDisplayPropertiesDefinition" = custom_field()
    index: int = custom_field()
    redacted: bool = custom_field()
    ui_category_style: int = custom_field()


@custom_define()
class DestinyPlugSetDefinition(ManifestModel, HashObject):
    """
    Sometimes, we have large sets of reusable plugs that are defined identically and thus can (and in some cases, are so large that they *must*) be shared across the places where they are used. These are the definitions for those reusable sets of plugs.   See DestinyItemSocketEntryDefinition.plugSource and reusablePlugSetHash for the relationship between these reusable plug sets and the sockets that leverage them (for starters, Emotes).  As of the release of Shadowkeep (Late 2019), these will begin to be sourced from game content directly - which means there will be many more of them, but it also means we may not get all data that we used to get for them.  DisplayProperties, in particular, will no longer be guaranteed to contain valid information. We will make a best effort to guess what ought to be populated there where possible, but it will be invalid for many/most plug sets.

    None
    Attributes:
        display_properties: If you want to show these plugs in isolation, these are the display properties for them.
        hash: The unique identifier for this entity. Guaranteed to be unique for the type of entity, but not globally. When entities refer to each other in Destiny content, it is this hash that they are referring to.
        index: The index of the entity as it was found in the investment tables.
        is_fake_plug_set: Mostly for our debugging or reporting bugs, BNet is making "fake" plug sets in a desperate effort to reduce socket sizes.  If this is true, the plug set was generated by BNet: if it looks wrong, that's a good indicator that it's bungie.net that fucked this up.
        redacted: If this is true, then there is an entity with this identifier/type combination, but BNet is not yet allowed to show it. Sorry!
        reusable_plug_items: This is a list of pre-determined plugs that can be plugged into this socket, without the character having the plug in their inventory. If this list is populated, you will not be allowed to plug an arbitrary item in the socket: you will only be able to choose from one of these reusable plugs.
    """

    display_properties: "DestinyDisplayPropertiesDefinition" = custom_field()
    index: int = custom_field()
    is_fake_plug_set: bool = custom_field()
    redacted: bool = custom_field()
    reusable_plug_items: list["DestinyItemSocketEntryPlugItemRandomizedDefinition"] = custom_field(
        metadata={"type": """list[DestinyItemSocketEntryPlugItemRandomizedDefinition]"""}
    )



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Optional, Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import DestinyRecordState
    from bungio.models import DestinyPresentationNodeDefinition
    from bungio.models import DestinyObjectiveProgress
    from bungio.models import DestinyRecordDefinition


@custom_define()
class DestinyRecordsComponent(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        record_categories_root_node_hash: The hash for the root presentation node definition of Triumph categories.
        record_seals_root_node_hash: The hash for the root presentation node definition of Triumph Seals.
        records: _No description given by bungie._
        manifest_record_categories_root_node_hash: Manifest information for `record_categories_root_node_hash`
        manifest_record_seals_root_node_hash: Manifest information for `record_seals_root_node_hash`
    """

    record_categories_root_node_hash: int = custom_field()
    record_seals_root_node_hash: int = custom_field()
    records: dict[int, "DestinyRecordComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyRecordComponent]"""}
    )
    manifest_record_categories_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )
    manifest_record_seals_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(default=None)


@custom_define()
class DestinyRecordComponent(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        completed_count: If available, this is the number of times this record has been completed. For example, the number of times a seal title has been gilded.
        interval_objectives: _No description given by bungie._
        intervals_redeemed_count: _No description given by bungie._
        objectives: _No description given by bungie._
        reward_visibilty: If available, a list that describes which reward rewards should be shown (true) or hidden (false). This property is for regular record rewards, and not for interval objective rewards.
        state: _No description given by bungie._
    """

    completed_count: int = custom_field()
    interval_objectives: list["DestinyObjectiveProgress"] = custom_field(
        metadata={"type": """list[DestinyObjectiveProgress]"""}
    )
    intervals_redeemed_count: int = custom_field()
    objectives: list["DestinyObjectiveProgress"] = custom_field(metadata={"type": """list[DestinyObjectiveProgress]"""})
    reward_visibilty: list[bool] = custom_field(metadata={"type": """list[bool]"""})
    state: Union["DestinyRecordState", int] = custom_field(converter=enum_converter("DestinyRecordState"))


@custom_define()
class DestinyProfileRecordsComponent(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        active_score: Your 'active' Triumphs score.
        legacy_score: Your 'legacy' Triumphs score.
        lifetime_score: Your 'lifetime' Triumphs score.
        record_categories_root_node_hash: The hash for the root presentation node definition of Triumph categories.
        record_seals_root_node_hash: The hash for the root presentation node definition of Triumph Seals.
        records: _No description given by bungie._
        score: Your 'active' Triumphs score, maintained for backwards compatibility.
        tracked_record_hash: If this profile is tracking a record, this is the hash identifier of the record it is tracking.
        manifest_record_categories_root_node_hash: Manifest information for `record_categories_root_node_hash`
        manifest_record_seals_root_node_hash: Manifest information for `record_seals_root_node_hash`
        manifest_tracked_record_hash: Manifest information for `tracked_record_hash`
    """

    active_score: int = custom_field()
    legacy_score: int = custom_field()
    lifetime_score: int = custom_field()
    record_categories_root_node_hash: int = custom_field()
    record_seals_root_node_hash: int = custom_field()
    records: dict[int, "DestinyRecordComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyRecordComponent]"""}
    )
    score: int = custom_field()
    tracked_record_hash: int = custom_field()
    manifest_record_categories_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )
    manifest_record_seals_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(default=None)
    manifest_tracked_record_hash: Optional["DestinyRecordDefinition"] = custom_field(default=None)


@custom_define()
class DestinyCharacterRecordsComponent(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        featured_record_hashes: _No description given by bungie._
        record_categories_root_node_hash: The hash for the root presentation node definition of Triumph categories.
        record_seals_root_node_hash: The hash for the root presentation node definition of Triumph Seals.
        records: _No description given by bungie._
        manifest_record_categories_root_node_hash: Manifest information for `record_categories_root_node_hash`
        manifest_record_seals_root_node_hash: Manifest information for `record_seals_root_node_hash`
    """

    featured_record_hashes: list[int] = custom_field(metadata={"type": """list[int]"""})
    record_categories_root_node_hash: int = custom_field()
    record_seals_root_node_hash: int = custom_field()
    records: dict[int, "DestinyRecordComponent"] = custom_field(
        metadata={"type": """dict[int, DestinyRecordComponent]"""}
    )
    manifest_record_categories_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(
        default=None
    )
    manifest_record_seals_root_node_hash: Optional["DestinyPresentationNodeDefinition"] = custom_field(default=None)



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from datetime import datetime
from typing import Union, TYPE_CHECKING

from bungio.utils import enum_converter
from bungio.models.base import BaseModel, BaseEnum, custom_define, custom_field


if TYPE_CHECKING:
    from bungio.models import BungieMembershipType


@custom_define()
class AwaInitializeResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        correlation_id: ID used to get the token. Present this ID to the user as it will identify this specific request on their device.
        sent_to_self: True if the PUSH message will only be sent to the device that made this request.
    """

    correlation_id: str = custom_field()
    sent_to_self: bool = custom_field()


@custom_define()
class AwaPermissionRequested(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        affected_item_id: Item instance ID the action shall be applied to. This is optional for all but a new AwaType values. Rule of thumb is to provide the item instance ID if one is available.
        character_id: Destiny character ID, if applicable, that will be affected by the action.
        membership_type: Destiny membership type of the account to modify.
        type: Type of advanced write action.
    """

    affected_item_id: int = custom_field(metadata={"int64": True})
    character_id: int = custom_field(metadata={"int64": True})
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    type: Union["AwaType", int] = custom_field(converter=enum_converter("AwaType"))


class AwaType(BaseEnum):
    """
    _No description given by bungie._
    """

    NONE = 0
    """_No description given by bungie._ """
    INSERT_PLUGS = 1
    """Insert plugs into sockets. """


@custom_define()
class AwaUserResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        correlation_id: Correlation ID of the request
        nonce: Secret nonce received via the PUSH notification.
        selection: Indication of the selection the user has made (Approving or rejecting the action)
    """

    correlation_id: str = custom_field()
    nonce: list[int] = custom_field(metadata={"type": """list[int]"""})
    selection: Union["AwaUserSelection", int] = custom_field(converter=enum_converter("AwaUserSelection"))


class AwaUserSelection(BaseEnum):
    """
    _No description given by bungie._
    """

    NONE = 0
    """_No description given by bungie._ """
    REJECTED = 1
    """_No description given by bungie._ """
    APPROVED = 2
    """_No description given by bungie._ """


@custom_define()
class AwaAuthorizationResult(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        action_token: Credential used to prove the user authorized an advanced write action.
        developer_note: Message to the app developer to help understand the response.
        maximum_number_of_uses: This token may be used to perform the requested action this number of times, at a maximum. If this value is 0, then there is no limit.
        membership_type: MembershipType from the permission request.
        response_reason: _No description given by bungie._
        type: Advanced Write Action Type from the permission request.
        user_selection: Indication of how the user responded to the request. If the value is "Approved" the actionToken will contain the token that can be presented when performing the advanced write action.
        valid_until: Time, UTC, when token expires.
    """

    action_token: str = custom_field()
    developer_note: str = custom_field()
    maximum_number_of_uses: int = custom_field()
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    response_reason: Union["AwaResponseReason", int] = custom_field(converter=enum_converter("AwaResponseReason"))
    type: Union["AwaType", int] = custom_field(converter=enum_converter("AwaType"))
    user_selection: Union["AwaUserSelection", int] = custom_field(converter=enum_converter("AwaUserSelection"))
    valid_until: datetime = custom_field()


class AwaResponseReason(BaseEnum):
    """
    _No description given by bungie._
    """

    NONE = 0
    """_No description given by bungie._ """
    ANSWERED = 1
    """User provided an answer """
    TIMED_OUT = 2
    """The HTTP request timed out, a new request may be made and an answer may still be provided. """
    REPLACED = 3
    """This request was replaced by another request. """
